<?php
/**
 * Kids Online Store Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Kids Online Store
 */

if ( ! defined( 'KIDS_ONLINE_STORE_URL' ) ) {
    define( 'KIDS_ONLINE_STORE_URL', esc_url( 'https://www.themagnifico.net/products/kids-wordpress-theme', 'kids-online-store') );
}
if ( ! defined( 'KIDS_ONLINE_STORE_TEXT' ) ) {
    define( 'KIDS_ONLINE_STORE_TEXT', __( 'Kids Online Store Pro','kids-online-store' ));
}
if ( ! defined( 'KIDS_ONLINE_STORE_BUY_TEXT' ) ) {
    define( 'KIDS_ONLINE_STORE_BUY_TEXT', __( 'Buy Kids Online Store Pro','kids-online-store' ));
}

use WPTRT\Customize\Section\Kids_Online_Store_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Kids_Online_Store_Button::class );

    $manager->add_section(
        new Kids_Online_Store_Button( $manager, 'kids_online_store_pro', [
            'title'       => esc_html( KIDS_ONLINE_STORE_TEXT,'kids-online-store' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'kids-online-store' ),
            'button_url'  => esc_url( KIDS_ONLINE_STORE_URL )
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'kids-online-store-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'kids-online-store-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function kids_online_store_customize_register($wp_customize){

    // Pro Version
    class Kids_Online_Store_Customize_Pro_Version extends WP_Customize_Control {
        public $type = 'pro_options';

        public function render_content() {
            echo '<span>For More <strong>'. esc_html( $this->label ) .'</strong>?</span>';
            echo '<a href="'. esc_url($this->description) .'" target="_blank">';
                echo '<span class="dashicons dashicons-info"></span>';
                echo '<strong> '. esc_html( KIDS_ONLINE_STORE_BUY_TEXT,'kids-online-store' ) .'<strong></a>';
            echo '</a>';
        }
    }

    // Custom Controls
    function Kids_Online_Store_sanitize_custom_control( $input ) {
        return $input;
    }

    //Logo
    $wp_customize->add_setting('kids_online_store_logo_max_height',array(
        'default'   => '24',
        'sanitize_callback' => 'kids_online_store_sanitize_number_absint'
    ));
    $wp_customize->add_control('kids_online_store_logo_max_height',array(
        'label' => esc_html__('Logo Width','kids-online-store'),
        'section'   => 'title_tagline',
        'type'      => 'number'
    ));

    $wp_customize->add_setting('kids_online_store_logo_title', array(
        'default' => true,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_logo_title',array(
        'label'          => __( 'Enable Disable Title', 'kids-online-store' ),
        'section'        => 'title_tagline',
        'settings'       => 'kids_online_store_logo_title',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_theme_description', array(
        'default' => false,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_theme_description',array(
        'label'          => __( 'Enable Disable Tagline', 'kids-online-store' ),
        'section'        => 'title_tagline',
        'settings'       => 'kids_online_store_theme_description',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_logo_title_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'kids_online_store_logo_title_color', array(
        'label'    => __('Site Title Color', 'kids-online-store'),
        'section'  => 'title_tagline'
    )));

    $wp_customize->add_setting('kids_online_store_logo_tagline_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'kids_online_store_logo_tagline_color', array(
        'label'    => __('Site Tagline Color', 'kids-online-store'),
        'section'  => 'title_tagline'
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_logo', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_logo', array(
        'section'     => 'title_tagline',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    // General Settings
   $wp_customize->add_section('kids_online_store_general_settings',array(
      'title' => esc_html__('General Settings','kids-online-store'),
      'priority'   => 30,
  ));

  $wp_customize->add_setting('kids_online_store_preloader_hide', array(
      'default' => false,
      'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
  ));
  $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_preloader_hide',array(
      'label'          => __( 'Show Theme Preloader', 'kids-online-store' ),
      'section'        => 'kids_online_store_general_settings',
      'settings'       => 'kids_online_store_preloader_hide',
      'type'           => 'checkbox',
  )));
  
   $wp_customize->add_setting( 'kids_online_store_preloader_bg_color', array(
        'default' => '#000',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_online_store_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','kids-online-store'),
        'section' => 'kids_online_store_general_settings',
        'settings' => 'kids_online_store_preloader_bg_color'
    )));

    $wp_customize->add_setting( 'kids_online_store_preloader_dot_1_color', array(
        'default' => '#fff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_online_store_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','kids-online-store'),
        'section' => 'kids_online_store_general_settings',
        'settings' => 'kids_online_store_preloader_dot_1_color'
    )));

    $wp_customize->add_setting( 'kids_online_store_preloader_dot_2_color', array(
        'default' => '#f10026',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_online_store_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','kids-online-store'),
        'section' => 'kids_online_store_general_settings',
        'settings' => 'kids_online_store_preloader_dot_2_color'
    )));

    $wp_customize->add_setting('kids_online_store_sticky_header', array(
        'default' => false,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_sticky_header',array(
        'label'          => __( 'Show Sticky Header', 'kids-online-store' ),
        'section'        => 'kids_online_store_general_settings',
        'settings'       => 'kids_online_store_sticky_header',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_scroll_hide', array(
      'default' => '',
      'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_scroll_hide',array(
      'label'          => __( 'Show Theme Scroll To Top', 'kids-online-store' ),
      'section'        => 'kids_online_store_general_settings',
      'settings'       => 'kids_online_store_scroll_hide',
      'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_scroll_top_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_scroll_top_position',array(
        'type' => 'radio',
        'section' => 'kids_online_store_general_settings',
        'choices' => array(
            'Right' => __('Right','kids-online-store'),
            'Left' => __('Left','kids-online-store'),
            'Center' => __('Center','kids-online-store')
        ),
    ) );

    //Woocommerce shop page Sidebar
    $wp_customize->add_setting('kids_online_store_woocommerce_shop_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_woocommerce_shop_page_sidebar',array(
        'label'          => __( 'Hide Shop Page Sidebar', 'kids-online-store' ),
        'section'        => 'kids_online_store_general_settings',
        'settings'       => 'kids_online_store_woocommerce_shop_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_shop_page_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_shop_page_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Shop Page Sidebar','kids-online-store'),
        'section' => 'kids_online_store_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','kids-online-store'),
            'Right Sidebar' => __('Right Sidebar','kids-online-store'),
        ),
    ) );

    //Woocommerce Single Product page Sidebar
    $wp_customize->add_setting('kids_online_store_woocommerce_single_product_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_woocommerce_single_product_page_sidebar',array(
        'label'          => __( 'Hide Single Product Page Sidebar', 'kids-online-store' ),
        'section'        => 'kids_online_store_general_settings',
        'settings'       => 'kids_online_store_woocommerce_single_product_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_single_product_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_single_product_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Single Product Page Sidebar','kids-online-store'),
        'section' => 'kids_online_store_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','kids-online-store'),
            'Right Sidebar' => __('Right Sidebar','kids-online-store'),
        ),
    ) );

    $wp_customize->add_setting( 'kids_online_store_woo_product_border_radius', array(
        'default'              => '',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'kids_online_store_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'kids_online_store_woo_product_border_radius', array(
        'label'       => esc_html__( 'Woocommerce Product Border Radius','kids-online-store' ),
        'section'     => 'kids_online_store_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 175,
        ),
    ) );

    $wp_customize->add_setting('kids_online_store_woocommerce_product_sale',array(
        'default' => 'Left',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_woocommerce_product_sale',array(
        'label'       => esc_html__( 'Woocommerce Product Sale Positions','kids-online-store' ),
        'type' => 'radio',
        'section' => 'kids_online_store_general_settings',
        'choices' => array(
            'Right' => __('Right','kids-online-store'),
            'Left' => __('Left','kids-online-store'),
            'Center' => __('Center','kids-online-store')
        ),
    ) );

    $wp_customize->add_setting( 'kids_online_store_woo_product_sale_border_radius', array(
        'default'              => '',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'kids_online_store_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'kids_online_store_woo_product_sale_border_radius', array(
        'label'       => esc_html__( 'Woocommerce Product Sale Border Radius','kids-online-store' ),
        'section'     => 'kids_online_store_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    // Pro Version
    $wp_customize->add_setting( 'pro_version_general_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_general_setting', array(
        'section'     => 'kids_online_store_general_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    // Post Settings
     $wp_customize->add_section('kids_online_store_post_settings',array(
        'title' => esc_html__('Post Settings','kids-online-store'),
        'priority'   =>40,
    ));

    $wp_customize->add_setting('kids_online_store_post_page_title',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_post_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Title', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable title on post page.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_post_page_meta',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_post_page_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Meta', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable meta on post page.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_meta_field_single_separator',array(
        'default'=> '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_meta_field_single_separator',array(
        'label' => __('Add Meta Separator','kids-online-store'),
        'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','kids-online-store'),
        'section'=> 'kids_online_store_single_blog_settings',
        'type'=> 'text'
    ));

    $wp_customize->add_setting('kids_online_store_post_page_thumb',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_post_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Thumbnail', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable thumbnail on post page.', 'kids-online-store'),
    ));

    $wp_customize->add_setting( 'kids_online_store_post_page_image_box_shadow', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'kids_online_store_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'kids_online_store_post_page_image_box_shadow', array(
        'label'       => esc_html__( 'Post Page Image Box Shadow','kids-online-store' ),
        'section'     => 'kids_online_store_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting('kids_online_store_post_page_content',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_post_page_content',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Content', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable content on post page.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_post_page_cat',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_post_page_cat',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Category and Tags', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable category and tags on post page.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_single_post_thumb',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_single_post_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Thumbnail', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable post thumbnail on single post.', 'kids-online-store'),
    ));

    $wp_customize->add_setting( 'kids_online_store_single_post_page_image_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'kids_online_store_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'kids_online_store_single_post_page_image_border_radius', array(
        'label'       => esc_html__( 'Single Post Page Image Border Radius','kids-online-store' ),
        'section'     => 'kids_online_store_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting( 'kids_online_store_single_post_page_image_box_shadow', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'kids_online_store_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'kids_online_store_single_post_page_image_box_shadow', array(
        'label'       => esc_html__( 'Single Post Page Image Box Shadow','kids-online-store' ),
        'section'     => 'kids_online_store_post_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    $wp_customize->add_setting('kids_online_store_single_post_meta',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_single_post_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Meta', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable single post meta such as post date, author, category, comment etc.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_single_post_title',array(
            'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_single_post_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Title', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable title on single post.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_single_post_page_content',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_single_post_page_content',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Page Content', 'kids-online-store'),
        'section'     => 'kids_online_store_post_settings',
        'description' => esc_html__('Check this box to enable content on single post page.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_single_post_navigation_show_hide',array(
        'default' => true,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('kids_online_store_single_post_navigation_show_hide',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Post Navigation','kids-online-store'),
        'section' => 'kids_online_store_post_settings',
    ));

    $wp_customize->add_setting('kids_online_store_single_post_comment_title',array(
        'default'=> 'Leave a Reply',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('kids_online_store_single_post_comment_title',array(
        'label' => __('Add Comment Title','kids-online-store'),
        'input_attrs' => array(
        'placeholder' => __( 'Leave a Reply', 'kids-online-store' ),
        ),
        'section'=> 'kids_online_store_post_settings',
        'type'=> 'text'
    ));

    $wp_customize->add_setting('kids_online_store_single_post_comment_btn_text',array(
        'default'=> 'Post Comment',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('kids_online_store_single_post_comment_btn_text',array(
        'label' => __('Add Comment Button Text','kids-online-store'),
        'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'kids-online-store' ),
        ),
        'section'=> 'kids_online_store_post_settings',
        'type'=> 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_post_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_post_setting', array(
        'section'     => 'kids_online_store_post_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    // Page Settings
    $wp_customize->add_section('kids_online_store_page_settings',array(
        'title' => esc_html__('Page Settings','kids-online-store'),
        'priority'   =>50,
    ));

    $wp_customize->add_setting('kids_online_store_single_page_title',array(
            'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_single_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Title', 'kids-online-store'),
        'section'     => 'kids_online_store_page_settings',
        'description' => esc_html__('Check this box to enable title on single page.', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_single_page_thumb',array(
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('kids_online_store_single_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Thumbnail', 'kids-online-store'),
        'section'     => 'kids_online_store_page_settings',
        'description' => esc_html__('Check this box to enable page thumbnail on single page.', 'kids-online-store'),
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_single_page_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_single_page_setting', array(
        'section'     => 'kids_online_store_page_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    // Theme Color
    $wp_customize->add_section('kids_online_store_color_option',array(
        'title' => esc_html__('Theme Color','kids-online-store'),
        'priority'   => 10,
    ));

    $wp_customize->add_setting( 'kids_online_store_theme_color_one', array(
        'default' => '',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_online_store_theme_color_one', array(
        'label' => esc_html__('First Color Option','kids-online-store'),
        'section' => 'kids_online_store_color_option',
        'settings' => 'kids_online_store_theme_color_one'
    )));

    $wp_customize->add_setting( 'kids_online_store_theme_color_two', array(
        'default' => '',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_online_store_theme_color_two', array(
        'label' => esc_html__('Second Color Option','kids-online-store'),
        'section' => 'kids_online_store_color_option',
        'settings' => 'kids_online_store_theme_color_two'
    )));

     // Pro Version
    $wp_customize->add_setting( 'pro_version_theme_color', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_theme_color', array(
        'section'     => 'kids_online_store_color_option',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    // Top Header
    $wp_customize->add_section('kids_online_store_top_header',array(
        'title' => esc_html__('Top Header','kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_top_header_setting', array(
        'default' => 0,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_top_header_setting',array(
        'label'          => __( 'Enable Disable Top Header', 'kids-online-store' ),
        'section'        => 'kids_online_store_top_header',
        'settings'       => 'kids_online_store_top_header_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_phone_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_phone_icon',array(
        'label' => esc_html__('Phone Icon','kids-online-store'),
        'section' => 'kids_online_store_top_header',
        'setting' => 'kids_online_store_phone_icon',
        'type'  => 'text',
        'default' => 'fa fa-phone-square',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fas fa-phone','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_phone_number_info',array(
        'default' => '',
        'sanitize_callback' => 'kids_online_store_sanitize_phone_number'
    ));
    $wp_customize->add_control('kids_online_store_phone_number_info',array(
        'label' => esc_html__('Phone Number','kids-online-store'),
        'section' => 'kids_online_store_top_header',
        'setting' => 'kids_online_store_phone_number_info',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('kids_online_store_email_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_email_icon',array(
        'label' => esc_html__('Email Icon','kids-online-store'),
        'section' => 'kids_online_store_top_header',
        'setting' => 'kids_online_store_email_icon',
        'type'  => 'text',
        'default' => 'fas fa-envelope-square',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fas fa-envelope','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_email_info',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_email'
    ));
    $wp_customize->add_control('kids_online_store_email_info',array(
        'label' => esc_html__('Email Address','kids-online-store'),
        'section' => 'kids_online_store_top_header',
        'setting' => 'kids_online_store_email_info',
        'type'  => 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_header_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_header_setting', array(
        'section'     => 'kids_online_store_top_header',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    // Social Link
    $wp_customize->add_section('kids_online_store_social_link',array(
        'title' => esc_html__('Social Links','kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_social_icon_setting', array(
        'default' => 0,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_social_icon_setting',array(
        'label'          => __( 'Enable Disable Social Icon', 'kids-online-store' ),
        'section'        => 'kids_online_store_social_link',
        'settings'       => 'kids_online_store_social_icon_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_facebook_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_facebook_icon',array(
        'label' => esc_html__('Social Icon','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_facebook_icon',
        'type'  => 'text',
        'default' => 'fab fa-facebook-f',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-facebook-f','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('kids_online_store_facebook_url',array(
        'label' => esc_html__('Facebook Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_twitter_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_twitter_icon',array(
        'label' => esc_html__('Social Icon','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_twitter_icon',
        'type'  => 'text',
        'default' => 'fab fa-twitter',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-twitter','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('kids_online_store_twitter_url',array(
        'label' => esc_html__('Twitter Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_instagram_icon',array(
       'default' => '',
       'sanitize_callback' => 'sanitize_text_field'
   ));
   $wp_customize->add_control('kids_online_store_instagram_icon',array(
       'label' => esc_html__('Social Icon','kids-online-store'),
       'section' => 'kids_online_store_social_link',
       'setting' => 'kids_online_store_instagram_icon',
       'type'  => 'text',
       'default' => 'fab fa-instagram',
       'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-instagram','kids-online-store')
   ));

    $wp_customize->add_setting('kids_online_store_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('kids_online_store_intagram_url',array(
        'label' => esc_html__('Intagram Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_linkedin_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_linkedin_icon',array(
        'label' => esc_html__('Social Icon','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_linkedin_icon',
        'type'  => 'text',
        'default' => 'fab fa-linkedin-in',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-linkedin-in','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('kids_online_store_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('kids_online_store_pinterest_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_pinterest_icon',array(
        'label' => esc_html__('Social Icon','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_pinterest_icon',
        'type'  => 'text',
        'default' => 'fab fa-pinterest-p',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-pinterest-p','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_pintrest_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('kids_online_store_pintrest_url',array(
        'label' => esc_html__('Pinterest Link','kids-online-store'),
        'section' => 'kids_online_store_social_link',
        'setting' => 'kids_online_store_pintrest_url',
        'type'  => 'url'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_social_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_social_setting', array(
        'section'     => 'kids_online_store_social_link',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    //Slider
    $wp_customize->add_section('kids_online_store_top_slider',array(
        'title' => esc_html__('Slider Settings','kids-online-store'),
        'description' => esc_html__('Here you have to add 3 different pages in below dropdown. Note: Image Dimensions 1200 x 550 px','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_slider_setting', array(
        'default' => 0,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_slider_setting',array(
        'label'          => __( 'Enable Disable Slider', 'kids-online-store' ),
        'section'        => 'kids_online_store_top_slider',
        'settings'       => 'kids_online_store_slider_setting',
        'type'           => 'checkbox',
    )));

    for ( $kids_online_store_count = 1; $kids_online_store_count <= 3; $kids_online_store_count++ ) {

        $wp_customize->add_setting( 'kids_online_store_top_slider_page' . $kids_online_store_count, array(
            'default'           => '',
            'sanitize_callback' => 'kids_online_store_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'kids_online_store_top_slider_page' . $kids_online_store_count, array(
            'label'    => __( 'Select Slide Page', 'kids-online-store' ),
            'description' => __('Slider image size (1400 x 750)','kids-online-store'),
            'section'  => 'kids_online_store_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    //Slider Image Opacity
    $wp_customize->add_setting('kids_online_store_slider_opacity_color',array(
      'default' => '1',
      'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));

    $wp_customize->add_control( 'kids_online_store_slider_opacity_color', array(
    'label'       => esc_html__( 'Slider Image Opacity','kids-online-store' ),
    'section'     => 'kids_online_store_top_slider',
    'type'        => 'select',
    'choices' => array(
      '0' =>  esc_attr('0','kids-online-store'),
      '0.1' =>  esc_attr('0.1','kids-online-store'),
      '0.2' =>  esc_attr('0.2','kids-online-store'),
      '0.3' =>  esc_attr('0.3','kids-online-store'),
      '0.4' =>  esc_attr('0.4','kids-online-store'),
      '0.5' =>  esc_attr('0.5','kids-online-store'),
      '0.6' =>  esc_attr('0.6','kids-online-store'),
      '0.7' =>  esc_attr('0.7','kids-online-store'),
      '0.8' =>  esc_attr('0.8','kids-online-store'),
      '0.9' =>  esc_attr('0.9','kids-online-store')
    ),
    ));

    //Slider height
    $wp_customize->add_setting('kids_online_store_slider_img_height',array(
        'default'=> '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('kids_online_store_slider_img_height',array(
        'label' => __('Slider Height','kids-online-store'),
        'description'   => __('Add the slider height in px(eg. 500px).','kids-online-store'),
        'input_attrs' => array(
            'placeholder' => __( '500px', 'kids-online-store' ),
        ),
        'section'=> 'kids_online_store_top_slider',
        'type'=> 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_slider_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_slider_setting', array(
        'section'     => 'kids_online_store_top_slider',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    //Home Page Product Category
    $wp_customize->add_section('kids_online_store_home_product_category',array(
        'title' => esc_html__('Home Product Category','kids-online-store'),
        'description' => esc_html__('Here you have to select product category which will display perticular product category, products in the home page.','kids-online-store')
    ));

    $wp_customize->add_setting('kids_online_store_product_setting', array(
        'default' => 0,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'kids_online_store_product_setting',array(
        'label'          => __( 'Enable Disable Product', 'kids-online-store' ),
        'section'        => 'kids_online_store_home_product_category',
        'settings'       => 'kids_online_store_product_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('kids_online_store_home_product_number',array(
        'default' => '',
        'sanitize_callback' => 'kids_online_store_sanitize_number_absint'
    ));
    $wp_customize->add_control('kids_online_store_home_product_number',array(
        'label' => __('No Of Products To Show','kids-online-store'),
        'section' => 'kids_online_store_home_product_category',
        'setting' => 'kids_online_store_home_product_number',
        'type'    => 'number'
    ));

    $kids_online_store_args = array(
       'type'                     => 'product',
        'child_of'                 => 0,
        'parent'                   => '',
        'orderby'                  => 'term_group',
        'order'                    => 'ASC',
        'hide_empty'               => false,
        'hierarchical'             => 1,
        'number'                   => '',
        'taxonomy'                 => 'product_cat',
        'pad_counts'               => false
    );
    $categories = get_categories( $kids_online_store_args );
    $cats = array();
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cats[$category->slug] = $category->name;
    }
    $wp_customize->add_setting('kids_online_store_home_product',array(
        'sanitize_callback' => 'kids_online_store_sanitize_select',
    ));
    $wp_customize->add_control('kids_online_store_home_product',array(
        'type'    => 'select',
        'choices' => $cats,
        'label' => __('Select Product Category','kids-online-store'),
        'section' => 'kids_online_store_home_product_category',
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_product_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_product_setting', array(
        'section'     => 'kids_online_store_home_product_category',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));

    // Footer
    $wp_customize->add_section('kids_online_store_site_footer_section', array(
        'title' => esc_html__('Footer', 'kids-online-store'),
    ));

    $wp_customize->add_setting('kids_online_store_footer_background_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'kids_online_store_footer_background_color', array(
        'label'    => __('Footer Background Color', 'kids-online-store'),
        'section'  => 'kids_online_store_site_footer_section',
        'priority' => 1,
    )));

    $wp_customize->add_setting('kids_online_store_footer_bg_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'kids_online_store_footer_bg_image',array(
        'label' => __('Footer Background Image','kids-online-store'),
        'section' => 'kids_online_store_site_footer_section',
    )));

     $wp_customize->add_setting('kids_online_store_footer_bg_image_position',array(
        'default'=> 'scroll',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_footer_bg_image_position',array(
        'type' => 'select',
        'label' => __('Footer Background Image Position','kids-online-store'),
        'choices' => array(
            'fixed' => __('fixed','kids-online-store'),
            'scroll' => __('scroll','kids-online-store'),
        ),
        'section'=> 'kids_online_store_site_footer_section',
    ));

    $wp_customize->add_setting('kids_online_store_footer_widget_heading_alignment',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_footer_widget_heading_alignment',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading Alignment','kids-online-store'),
        'section' => 'kids_online_store_site_footer_section',
        'choices' => array(
            'Left' => __('Left','kids-online-store'),
            'Center' => __('Center','kids-online-store'),
            'Right' => __('Right','kids-online-store')
        ),
    ) );

    $wp_customize->add_setting('kids_online_store_footer_widget_content_alignment',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_footer_widget_content_alignment',array(
        'type' => 'select',
        'label' => __('Footer Widget Content Alignment','kids-online-store'),
        'section' => 'kids_online_store_site_footer_section',
        'choices' => array(
            'Left' => __('Left','kids-online-store'),
            'Center' => __('Center','kids-online-store'),
            'Right' => __('Right','kids-online-store')
        ),
    ) );

    $wp_customize->add_setting('kids_online_store_show_hide_copyright',array(
        'default' => true,
        'sanitize_callback' => 'kids_online_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('kids_online_store_show_hide_copyright',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Copyright','kids-online-store'),
        'section' => 'kids_online_store_site_footer_section',
    ));

    $wp_customize->add_setting('kids_online_store_copyright_content_alignment',array(
        'default' => 'Right',
        'transport' => 'refresh',
        'sanitize_callback' => 'kids_online_store_sanitize_choices'
    ));
    $wp_customize->add_control('kids_online_store_copyright_content_alignment',array(
        'type' => 'select',
        'label' => __('Copyright Content Alignment','kids-online-store'),
        'section' => 'kids_online_store_site_footer_section',
        'choices' => array(
            'Left' => __('Left','kids-online-store'),
            'Center' => __('Center','kids-online-store'),
            'Right' => __('Right','kids-online-store')
        ),
    ) );

    $wp_customize->add_setting('kids_online_store_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('kids_online_store_footer_text_setting', array(
        'label' => __('Replace the footer text', 'kids-online-store'),
        'section' => 'kids_online_store_site_footer_section',
        'type' => 'text',
    ));

    $wp_customize->add_setting('kids_online_store_copyright_background_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'kids_online_store_copyright_background_color', array(
        'label'    => __('Copyright Background Color', 'kids-online-store'),
        'section'  => 'kids_online_store_site_footer_section',
    )));

     // Pro Version
    $wp_customize->add_setting( 'pro_version_footer_setting', array(
        'sanitize_callback' => 'Kids_Online_Store_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Kids_Online_Store_Customize_Pro_Version ( $wp_customize,'pro_version_footer_setting', array(
        'section'     => 'kids_online_store_site_footer_section',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'kids-online-store' ),
        'description' => esc_url( KIDS_ONLINE_STORE_URL ),
        'priority'    => 100
    )));
}
add_action('customize_register', 'kids_online_store_customize_register');

/*
** Load dynamic logic for the customizer controls area.
*/
function kids_online_store_panels_js() {
    wp_enqueue_style( 'kids-online-store-customizer-layout-css', get_theme_file_uri( '/assets/css/customizer-layout.css' ) );
    wp_enqueue_script( 'kids-online-store-customize-layout', get_theme_file_uri( '/assets/js/customize-layout.js' ), array(), '1.2', true );
}
add_action( 'customize_controls_enqueue_scripts', 'kids_online_store_panels_js' );
